# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: steammessages_clientserver_userstats.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


import steam.protobufs.steammessages_base_pb2 as steammessages__base__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='steammessages_clientserver_userstats.proto',
  package='',
  syntax='proto2',
  serialized_options=b'H\001\220\001\000',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n*steammessages_clientserver_userstats.proto\x1a\x18steammessages_base.proto\"u\n\x16\x43MsgClientGetUserStats\x12\x0f\n\x07game_id\x18\x01 \x01(\x06\x12\x11\n\tcrc_stats\x18\x02 \x01(\r\x12\x1c\n\x14schema_local_version\x18\x03 \x01(\x05\x12\x19\n\x11steam_id_for_user\x18\x04 \x01(\x06\"\xdf\x02\n\x1e\x43MsgClientGetUserStatsResponse\x12\x0f\n\x07game_id\x18\x01 \x01(\x06\x12\x12\n\x07\x65result\x18\x02 \x01(\x05:\x01\x32\x12\x11\n\tcrc_stats\x18\x03 \x01(\r\x12\x0e\n\x06schema\x18\x04 \x01(\x0c\x12\x34\n\x05stats\x18\x05 \x03(\x0b\x32%.CMsgClientGetUserStatsResponse.Stats\x12N\n\x12\x61\x63hievement_blocks\x18\x06 \x03(\x0b\x32\x32.CMsgClientGetUserStatsResponse.Achievement_Blocks\x1a,\n\x05Stats\x12\x0f\n\x07stat_id\x18\x01 \x01(\r\x12\x12\n\nstat_value\x18\x02 \x01(\r\x1a\x41\n\x12\x41\x63hievement_Blocks\x12\x16\n\x0e\x61\x63hievement_id\x18\x01 \x01(\r\x12\x13\n\x0bunlock_time\x18\x02 \x03(\x07\"\x9a\x02\n CMsgClientStoreUserStatsResponse\x12\x0f\n\x07game_id\x18\x01 \x01(\x06\x12\x12\n\x07\x65result\x18\x02 \x01(\x05:\x01\x32\x12\x11\n\tcrc_stats\x18\x03 \x01(\r\x12Z\n\x17stats_failed_validation\x18\x04 \x03(\x0b\x32\x39.CMsgClientStoreUserStatsResponse.Stats_Failed_Validation\x12\x19\n\x11stats_out_of_date\x18\x05 \x01(\x08\x1aG\n\x17Stats_Failed_Validation\x12\x0f\n\x07stat_id\x18\x01 \x01(\r\x12\x1b\n\x13reverted_stat_value\x18\x02 \x01(\r\"\xe8\x01\n\x19\x43MsgClientStoreUserStats2\x12\x0f\n\x07game_id\x18\x01 \x01(\x06\x12\x17\n\x0fsettor_steam_id\x18\x02 \x01(\x06\x12\x17\n\x0fsettee_steam_id\x18\x03 \x01(\x06\x12\x11\n\tcrc_stats\x18\x04 \x01(\r\x12\x16\n\x0e\x65xplicit_reset\x18\x05 \x01(\x08\x12/\n\x05stats\x18\x06 \x03(\x0b\x32 .CMsgClientStoreUserStats2.Stats\x1a,\n\x05Stats\x12\x0f\n\x07stat_id\x18\x01 \x01(\r\x12\x12\n\nstat_value\x18\x02 \x01(\r\"\xc2\x01\n\x16\x43MsgClientStatsUpdated\x12\x10\n\x08steam_id\x18\x01 \x01(\x06\x12\x0f\n\x07game_id\x18\x02 \x01(\x06\x12\x11\n\tcrc_stats\x18\x03 \x01(\r\x12<\n\rupdated_stats\x18\x04 \x03(\x0b\x32%.CMsgClientStatsUpdated.Updated_Stats\x1a\x34\n\rUpdated_Stats\x12\x0f\n\x07stat_id\x18\x01 \x01(\r\x12\x12\n\nstat_value\x18\x02 \x01(\r\"\xbc\x01\n\x18\x43MsgClientStoreUserStats\x12\x0f\n\x07game_id\x18\x01 \x01(\x06\x12\x16\n\x0e\x65xplicit_reset\x18\x02 \x01(\x08\x12@\n\x0estats_to_store\x18\x03 \x03(\x0b\x32(.CMsgClientStoreUserStats.Stats_To_Store\x1a\x35\n\x0eStats_To_Store\x12\x0f\n\x07stat_id\x18\x01 \x01(\r\x12\x12\n\nstat_value\x18\x02 \x01(\rB\x05H\x01\x90\x01\x00'
  ,
  dependencies=[steammessages__base__pb2.DESCRIPTOR,])




_CMSGCLIENTGETUSERSTATS = _descriptor.Descriptor(
  name='CMsgClientGetUserStats',
  full_name='CMsgClientGetUserStats',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='game_id', full_name='CMsgClientGetUserStats.game_id', index=0,
      number=1, type=6, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='crc_stats', full_name='CMsgClientGetUserStats.crc_stats', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='schema_local_version', full_name='CMsgClientGetUserStats.schema_local_version', index=2,
      number=3, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='steam_id_for_user', full_name='CMsgClientGetUserStats.steam_id_for_user', index=3,
      number=4, type=6, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=72,
  serialized_end=189,
)


_CMSGCLIENTGETUSERSTATSRESPONSE_STATS = _descriptor.Descriptor(
  name='Stats',
  full_name='CMsgClientGetUserStatsResponse.Stats',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='stat_id', full_name='CMsgClientGetUserStatsResponse.Stats.stat_id', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='stat_value', full_name='CMsgClientGetUserStatsResponse.Stats.stat_value', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=432,
  serialized_end=476,
)

_CMSGCLIENTGETUSERSTATSRESPONSE_ACHIEVEMENT_BLOCKS = _descriptor.Descriptor(
  name='Achievement_Blocks',
  full_name='CMsgClientGetUserStatsResponse.Achievement_Blocks',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='achievement_id', full_name='CMsgClientGetUserStatsResponse.Achievement_Blocks.achievement_id', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='unlock_time', full_name='CMsgClientGetUserStatsResponse.Achievement_Blocks.unlock_time', index=1,
      number=2, type=7, cpp_type=3, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=478,
  serialized_end=543,
)

_CMSGCLIENTGETUSERSTATSRESPONSE = _descriptor.Descriptor(
  name='CMsgClientGetUserStatsResponse',
  full_name='CMsgClientGetUserStatsResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='game_id', full_name='CMsgClientGetUserStatsResponse.game_id', index=0,
      number=1, type=6, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='eresult', full_name='CMsgClientGetUserStatsResponse.eresult', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=True, default_value=2,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='crc_stats', full_name='CMsgClientGetUserStatsResponse.crc_stats', index=2,
      number=3, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='schema', full_name='CMsgClientGetUserStatsResponse.schema', index=3,
      number=4, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='stats', full_name='CMsgClientGetUserStatsResponse.stats', index=4,
      number=5, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='achievement_blocks', full_name='CMsgClientGetUserStatsResponse.achievement_blocks', index=5,
      number=6, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_CMSGCLIENTGETUSERSTATSRESPONSE_STATS, _CMSGCLIENTGETUSERSTATSRESPONSE_ACHIEVEMENT_BLOCKS, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=192,
  serialized_end=543,
)


_CMSGCLIENTSTOREUSERSTATSRESPONSE_STATS_FAILED_VALIDATION = _descriptor.Descriptor(
  name='Stats_Failed_Validation',
  full_name='CMsgClientStoreUserStatsResponse.Stats_Failed_Validation',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='stat_id', full_name='CMsgClientStoreUserStatsResponse.Stats_Failed_Validation.stat_id', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='reverted_stat_value', full_name='CMsgClientStoreUserStatsResponse.Stats_Failed_Validation.reverted_stat_value', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=757,
  serialized_end=828,
)

_CMSGCLIENTSTOREUSERSTATSRESPONSE = _descriptor.Descriptor(
  name='CMsgClientStoreUserStatsResponse',
  full_name='CMsgClientStoreUserStatsResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='game_id', full_name='CMsgClientStoreUserStatsResponse.game_id', index=0,
      number=1, type=6, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='eresult', full_name='CMsgClientStoreUserStatsResponse.eresult', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=True, default_value=2,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='crc_stats', full_name='CMsgClientStoreUserStatsResponse.crc_stats', index=2,
      number=3, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='stats_failed_validation', full_name='CMsgClientStoreUserStatsResponse.stats_failed_validation', index=3,
      number=4, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='stats_out_of_date', full_name='CMsgClientStoreUserStatsResponse.stats_out_of_date', index=4,
      number=5, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_CMSGCLIENTSTOREUSERSTATSRESPONSE_STATS_FAILED_VALIDATION, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=546,
  serialized_end=828,
)


_CMSGCLIENTSTOREUSERSTATS2_STATS = _descriptor.Descriptor(
  name='Stats',
  full_name='CMsgClientStoreUserStats2.Stats',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='stat_id', full_name='CMsgClientStoreUserStats2.Stats.stat_id', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='stat_value', full_name='CMsgClientStoreUserStats2.Stats.stat_value', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=432,
  serialized_end=476,
)

_CMSGCLIENTSTOREUSERSTATS2 = _descriptor.Descriptor(
  name='CMsgClientStoreUserStats2',
  full_name='CMsgClientStoreUserStats2',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='game_id', full_name='CMsgClientStoreUserStats2.game_id', index=0,
      number=1, type=6, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='settor_steam_id', full_name='CMsgClientStoreUserStats2.settor_steam_id', index=1,
      number=2, type=6, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='settee_steam_id', full_name='CMsgClientStoreUserStats2.settee_steam_id', index=2,
      number=3, type=6, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='crc_stats', full_name='CMsgClientStoreUserStats2.crc_stats', index=3,
      number=4, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='explicit_reset', full_name='CMsgClientStoreUserStats2.explicit_reset', index=4,
      number=5, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='stats', full_name='CMsgClientStoreUserStats2.stats', index=5,
      number=6, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_CMSGCLIENTSTOREUSERSTATS2_STATS, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=831,
  serialized_end=1063,
)


_CMSGCLIENTSTATSUPDATED_UPDATED_STATS = _descriptor.Descriptor(
  name='Updated_Stats',
  full_name='CMsgClientStatsUpdated.Updated_Stats',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='stat_id', full_name='CMsgClientStatsUpdated.Updated_Stats.stat_id', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='stat_value', full_name='CMsgClientStatsUpdated.Updated_Stats.stat_value', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1208,
  serialized_end=1260,
)

_CMSGCLIENTSTATSUPDATED = _descriptor.Descriptor(
  name='CMsgClientStatsUpdated',
  full_name='CMsgClientStatsUpdated',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='steam_id', full_name='CMsgClientStatsUpdated.steam_id', index=0,
      number=1, type=6, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='game_id', full_name='CMsgClientStatsUpdated.game_id', index=1,
      number=2, type=6, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='crc_stats', full_name='CMsgClientStatsUpdated.crc_stats', index=2,
      number=3, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='updated_stats', full_name='CMsgClientStatsUpdated.updated_stats', index=3,
      number=4, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_CMSGCLIENTSTATSUPDATED_UPDATED_STATS, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1066,
  serialized_end=1260,
)


_CMSGCLIENTSTOREUSERSTATS_STATS_TO_STORE = _descriptor.Descriptor(
  name='Stats_To_Store',
  full_name='CMsgClientStoreUserStats.Stats_To_Store',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='stat_id', full_name='CMsgClientStoreUserStats.Stats_To_Store.stat_id', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='stat_value', full_name='CMsgClientStoreUserStats.Stats_To_Store.stat_value', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1398,
  serialized_end=1451,
)

_CMSGCLIENTSTOREUSERSTATS = _descriptor.Descriptor(
  name='CMsgClientStoreUserStats',
  full_name='CMsgClientStoreUserStats',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='game_id', full_name='CMsgClientStoreUserStats.game_id', index=0,
      number=1, type=6, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='explicit_reset', full_name='CMsgClientStoreUserStats.explicit_reset', index=1,
      number=2, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='stats_to_store', full_name='CMsgClientStoreUserStats.stats_to_store', index=2,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_CMSGCLIENTSTOREUSERSTATS_STATS_TO_STORE, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1263,
  serialized_end=1451,
)

_CMSGCLIENTGETUSERSTATSRESPONSE_STATS.containing_type = _CMSGCLIENTGETUSERSTATSRESPONSE
_CMSGCLIENTGETUSERSTATSRESPONSE_ACHIEVEMENT_BLOCKS.containing_type = _CMSGCLIENTGETUSERSTATSRESPONSE
_CMSGCLIENTGETUSERSTATSRESPONSE.fields_by_name['stats'].message_type = _CMSGCLIENTGETUSERSTATSRESPONSE_STATS
_CMSGCLIENTGETUSERSTATSRESPONSE.fields_by_name['achievement_blocks'].message_type = _CMSGCLIENTGETUSERSTATSRESPONSE_ACHIEVEMENT_BLOCKS
_CMSGCLIENTSTOREUSERSTATSRESPONSE_STATS_FAILED_VALIDATION.containing_type = _CMSGCLIENTSTOREUSERSTATSRESPONSE
_CMSGCLIENTSTOREUSERSTATSRESPONSE.fields_by_name['stats_failed_validation'].message_type = _CMSGCLIENTSTOREUSERSTATSRESPONSE_STATS_FAILED_VALIDATION
_CMSGCLIENTSTOREUSERSTATS2_STATS.containing_type = _CMSGCLIENTSTOREUSERSTATS2
_CMSGCLIENTSTOREUSERSTATS2.fields_by_name['stats'].message_type = _CMSGCLIENTSTOREUSERSTATS2_STATS
_CMSGCLIENTSTATSUPDATED_UPDATED_STATS.containing_type = _CMSGCLIENTSTATSUPDATED
_CMSGCLIENTSTATSUPDATED.fields_by_name['updated_stats'].message_type = _CMSGCLIENTSTATSUPDATED_UPDATED_STATS
_CMSGCLIENTSTOREUSERSTATS_STATS_TO_STORE.containing_type = _CMSGCLIENTSTOREUSERSTATS
_CMSGCLIENTSTOREUSERSTATS.fields_by_name['stats_to_store'].message_type = _CMSGCLIENTSTOREUSERSTATS_STATS_TO_STORE
DESCRIPTOR.message_types_by_name['CMsgClientGetUserStats'] = _CMSGCLIENTGETUSERSTATS
DESCRIPTOR.message_types_by_name['CMsgClientGetUserStatsResponse'] = _CMSGCLIENTGETUSERSTATSRESPONSE
DESCRIPTOR.message_types_by_name['CMsgClientStoreUserStatsResponse'] = _CMSGCLIENTSTOREUSERSTATSRESPONSE
DESCRIPTOR.message_types_by_name['CMsgClientStoreUserStats2'] = _CMSGCLIENTSTOREUSERSTATS2
DESCRIPTOR.message_types_by_name['CMsgClientStatsUpdated'] = _CMSGCLIENTSTATSUPDATED
DESCRIPTOR.message_types_by_name['CMsgClientStoreUserStats'] = _CMSGCLIENTSTOREUSERSTATS
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

CMsgClientGetUserStats = _reflection.GeneratedProtocolMessageType('CMsgClientGetUserStats', (_message.Message,), {
  'DESCRIPTOR' : _CMSGCLIENTGETUSERSTATS,
  '__module__' : 'steammessages_clientserver_userstats_pb2'
  # @@protoc_insertion_point(class_scope:CMsgClientGetUserStats)
  })
_sym_db.RegisterMessage(CMsgClientGetUserStats)

CMsgClientGetUserStatsResponse = _reflection.GeneratedProtocolMessageType('CMsgClientGetUserStatsResponse', (_message.Message,), {

  'Stats' : _reflection.GeneratedProtocolMessageType('Stats', (_message.Message,), {
    'DESCRIPTOR' : _CMSGCLIENTGETUSERSTATSRESPONSE_STATS,
    '__module__' : 'steammessages_clientserver_userstats_pb2'
    # @@protoc_insertion_point(class_scope:CMsgClientGetUserStatsResponse.Stats)
    })
  ,

  'Achievement_Blocks' : _reflection.GeneratedProtocolMessageType('Achievement_Blocks', (_message.Message,), {
    'DESCRIPTOR' : _CMSGCLIENTGETUSERSTATSRESPONSE_ACHIEVEMENT_BLOCKS,
    '__module__' : 'steammessages_clientserver_userstats_pb2'
    # @@protoc_insertion_point(class_scope:CMsgClientGetUserStatsResponse.Achievement_Blocks)
    })
  ,
  'DESCRIPTOR' : _CMSGCLIENTGETUSERSTATSRESPONSE,
  '__module__' : 'steammessages_clientserver_userstats_pb2'
  # @@protoc_insertion_point(class_scope:CMsgClientGetUserStatsResponse)
  })
_sym_db.RegisterMessage(CMsgClientGetUserStatsResponse)
_sym_db.RegisterMessage(CMsgClientGetUserStatsResponse.Stats)
_sym_db.RegisterMessage(CMsgClientGetUserStatsResponse.Achievement_Blocks)

CMsgClientStoreUserStatsResponse = _reflection.GeneratedProtocolMessageType('CMsgClientStoreUserStatsResponse', (_message.Message,), {

  'Stats_Failed_Validation' : _reflection.GeneratedProtocolMessageType('Stats_Failed_Validation', (_message.Message,), {
    'DESCRIPTOR' : _CMSGCLIENTSTOREUSERSTATSRESPONSE_STATS_FAILED_VALIDATION,
    '__module__' : 'steammessages_clientserver_userstats_pb2'
    # @@protoc_insertion_point(class_scope:CMsgClientStoreUserStatsResponse.Stats_Failed_Validation)
    })
  ,
  'DESCRIPTOR' : _CMSGCLIENTSTOREUSERSTATSRESPONSE,
  '__module__' : 'steammessages_clientserver_userstats_pb2'
  # @@protoc_insertion_point(class_scope:CMsgClientStoreUserStatsResponse)
  })
_sym_db.RegisterMessage(CMsgClientStoreUserStatsResponse)
_sym_db.RegisterMessage(CMsgClientStoreUserStatsResponse.Stats_Failed_Validation)

CMsgClientStoreUserStats2 = _reflection.GeneratedProtocolMessageType('CMsgClientStoreUserStats2', (_message.Message,), {

  'Stats' : _reflection.GeneratedProtocolMessageType('Stats', (_message.Message,), {
    'DESCRIPTOR' : _CMSGCLIENTSTOREUSERSTATS2_STATS,
    '__module__' : 'steammessages_clientserver_userstats_pb2'
    # @@protoc_insertion_point(class_scope:CMsgClientStoreUserStats2.Stats)
    })
  ,
  'DESCRIPTOR' : _CMSGCLIENTSTOREUSERSTATS2,
  '__module__' : 'steammessages_clientserver_userstats_pb2'
  # @@protoc_insertion_point(class_scope:CMsgClientStoreUserStats2)
  })
_sym_db.RegisterMessage(CMsgClientStoreUserStats2)
_sym_db.RegisterMessage(CMsgClientStoreUserStats2.Stats)

CMsgClientStatsUpdated = _reflection.GeneratedProtocolMessageType('CMsgClientStatsUpdated', (_message.Message,), {

  'Updated_Stats' : _reflection.GeneratedProtocolMessageType('Updated_Stats', (_message.Message,), {
    'DESCRIPTOR' : _CMSGCLIENTSTATSUPDATED_UPDATED_STATS,
    '__module__' : 'steammessages_clientserver_userstats_pb2'
    # @@protoc_insertion_point(class_scope:CMsgClientStatsUpdated.Updated_Stats)
    })
  ,
  'DESCRIPTOR' : _CMSGCLIENTSTATSUPDATED,
  '__module__' : 'steammessages_clientserver_userstats_pb2'
  # @@protoc_insertion_point(class_scope:CMsgClientStatsUpdated)
  })
_sym_db.RegisterMessage(CMsgClientStatsUpdated)
_sym_db.RegisterMessage(CMsgClientStatsUpdated.Updated_Stats)

CMsgClientStoreUserStats = _reflection.GeneratedProtocolMessageType('CMsgClientStoreUserStats', (_message.Message,), {

  'Stats_To_Store' : _reflection.GeneratedProtocolMessageType('Stats_To_Store', (_message.Message,), {
    'DESCRIPTOR' : _CMSGCLIENTSTOREUSERSTATS_STATS_TO_STORE,
    '__module__' : 'steammessages_clientserver_userstats_pb2'
    # @@protoc_insertion_point(class_scope:CMsgClientStoreUserStats.Stats_To_Store)
    })
  ,
  'DESCRIPTOR' : _CMSGCLIENTSTOREUSERSTATS,
  '__module__' : 'steammessages_clientserver_userstats_pb2'
  # @@protoc_insertion_point(class_scope:CMsgClientStoreUserStats)
  })
_sym_db.RegisterMessage(CMsgClientStoreUserStats)
_sym_db.RegisterMessage(CMsgClientStoreUserStats.Stats_To_Store)


DESCRIPTOR._options = None
# @@protoc_insertion_point(module_scope)
